@@ -1,4 +1,4 @@
-from basepath.basec import driver,checkbyxpath
+from xpathwrapper.basec import driver,checkbyxpath
 
 driver.get('http://testing.pythonautomation.tk/')
 
